"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCurrentLocalISO = exports.lockCurrentTime = exports.createScheduleEvent = exports.createTrack = exports.generateTimeEvents = exports.createTimeRange = exports.convertEventTimeToLocal = exports.iso2sec = exports.convertEventTimeToISO = exports.getLocalTime = exports.getCestTime = exports.getCurrentTime = exports.setCurrentUTCTimeAndZone = exports.setGlobals = void 0;

var _luxon = require("luxon");

function _readOnlyError(name) { throw new Error("\"" + name + "\" is read-only"); }

var timeSettings = {
  currentUTCDiffMI: 0,
  currentUTCDiffDate: 0,
  currentDiffHH: 0,
  currentDiffMM: 0,
  currentTimezone: getClientTimezoneOffset()
};
var globalSettings = {
  conferenceStart: null,
  conferenceFinish: null
};

var setGlobals = function setGlobals(info) {
  Object.keys(info).forEach(function (key) {
    globalSettings[key] = info[key];
  });
};

exports.setGlobals = setGlobals;
var lockedCurrentTime = null; // const clientTimezone = getClientTimezoneOffset();

var initClientTime = getClientTime();

function getClientTimezoneOffset() {
  var minutes = -new Date().getTimezoneOffset();
  var hours = Math.floor(minutes / 60);
  var mm = minutes - hours * 60;
  var hhs = "".concat(hours).padStart(2, '0');
  var mms = "".concat(mm).padStart(2, '0');
  var str = "".concat(hhs).concat(mms);

  if (str.length !== 4) {
    return null;
  }

  return {
    str: str,
    hh: mm === 0 ? hours : null
  };
}

function getClientTime() {
  var clientYY = new Date().getFullYear();
  var clientMI = new Date().getMonth();
  var clientDD = new Date().getDate();
  var clientHH = new Date().getHours();
  var clientMM = new Date().getMinutes();
  var clientSS = new Date().getSeconds();
  var utcYY = new Date().getUTCFullYear();
  var utcMI = new Date().getUTCMonth();
  var utcDD = new Date().getUTCDate();
  var utcHH = new Date().getUTCHours();
  var utcMM = new Date().getUTCMinutes();
  var utcSS = new Date().getUTCSeconds();
  var clientLocalTime = new Date(clientYY, clientMI, clientDD, clientHH, clientMM, clientSS);
  var clientUTCTime = new Date(utcYY, utcMI, utcDD, utcHH, utcMM, utcSS);
  return {
    clientLocalTime: clientLocalTime,
    clientUTCTime: clientUTCTime,
    utcYY: utcYY,
    utcMI: utcMI,
    utcDD: utcDD,
    utcHH: utcHH,
    utcMM: utcMM,
    utcSS: utcSS
  };
}

var setCurrentUTCTimeAndZone = function setCurrentUTCTimeAndZone(_ref) {
  var mi = _ref.mi,
      date = _ref.date,
      hh = _ref.hh,
      mm = _ref.mm,
      offset = _ref.offset;
  var clientTime = getClientTime();
  var dmi = mi - clientTime.utcMI;
  var ddate = date - clientTime.utcDD;
  var dhh = hh - clientTime.utcHH;
  var dmm = mm - clientTime.utcMM;
  timeSettings = (_readOnlyError("timeSettings"), {
    currentUTCDiffMI: dmi,
    currentUTCDiffDate: ddate,
    currentDiffHH: dhh,
    currentDiffMM: dmm,
    currentTimezone: offset
  });
};

exports.setCurrentUTCTimeAndZone = setCurrentUTCTimeAndZone;

var getCurrentTime = function getCurrentTime() {
  var clientTime = getClientTime();
  var currentTime = {
    utcYY: clientTime.utcYY,
    utcMI: clientTime.utcMI + timeSettings.currentUTCDiffMI,
    utcDD: clientTime.utcDD + timeSettings.currentUTCDiffDate,
    utcHH: clientTime.utcHH + timeSettings.currentDiffHH,
    utcMM: clientTime.utcMM + timeSettings.currentDiffMM,
    utcSS: clientTime.utcSS
  };
  currentTime.UTCTime = new Date(clientTime.utcYY, clientTime.utcMI, clientTime.utcDD, clientTime.utcHH, clientTime.utcMM, clientTime.utcSS);
  return currentTime;
};

exports.getCurrentTime = getCurrentTime;

var getCestTime = function getCestTime() {};

exports.getCestTime = getCestTime;

var getLocalTime = function getLocalTime() {
  return new Date();
};

exports.getLocalTime = getLocalTime;

var convertEventTimeToISO = function convertEventTimeToISO(date, time) {
  var z = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
  var correctFormat = typeof z === 'string' ? 'MMMM dd HH:mm z' : 'MMMM dd HH:mm Z';
  var correctDateStr = typeof z === 'string' ? "".concat(date, " ").concat(time, " ").concat(z) : "".concat(date, " ").concat(time, " +").concat(z);

  var iso = _luxon.DateTime.fromFormat(correctDateStr, correctFormat).toISO();

  if (!iso) {// console.log('convertEventTimeToISO -> !!!\n', date, time, iso);
  }

  return iso;
};

exports.convertEventTimeToISO = convertEventTimeToISO;

var iso2sec = function iso2sec(iso) {
  return Math.floor(_luxon.DateTime.fromISO(iso).toMillis() / 1000);
};

exports.iso2sec = iso2sec;

var convertEventTimeToLocal = function convertEventTimeToLocal(iso) {
  var local = _luxon.DateTime.fromISO(iso);

  return {
    date: local.toFormat('dd MMM'),
    time: local.toFormat('HH:mm'),
    sec: iso2sec(iso)
  };
};

exports.convertEventTimeToLocal = convertEventTimeToLocal;

var createTimeRange = function createTimeRange(isoStart, isoEnd) {
  var difMM = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 5;
  var range = [];
  var difSS = difMM * 60;
  var secStart = iso2sec(isoStart);
  var secEnd = iso2sec(isoEnd);
  var i = secStart;

  while (i <= secEnd) {
    var tm = _luxon.DateTime.fromSeconds(i);

    var time = {
      date: tm.toFormat('dd MMM'),
      time: tm.toFormat('HH:mm')
    };
    range.push(time);
    i = i + difSS;
  }

  return range;
};

exports.createTimeRange = createTimeRange;

var generateTimeEvents = function generateTimeEvents(_ref2) {
  var isoStart = _ref2.isoStart,
      isoEnd = _ref2.isoEnd,
      cb = _ref2.cb,
      _ref2$difSS = _ref2.difSS,
      difSS = _ref2$difSS === void 0 ? 10 : _ref2$difSS;
  var secStart = iso2sec(isoStart);
  var secEnd = iso2sec(isoEnd);

  var checkRange = function checkRange(sec) {
    if (!isoStart || !isoEnd) {
      return true;
    }

    return secStart <= sec && sec <= secEnd;
  };

  var invokeCb = function invokeCb() {
    var currentIso = getCurrentLocalISO();
    var currentSec = iso2sec(currentIso);

    if (!checkRange(currentSec)) {
      return;
    }

    var tm = _luxon.DateTime.fromISO(currentIso);

    var time = {
      date: tm.toFormat('MMMM dd'),
      time: tm.toFormat('HH:mm'),
      z: tm.zoneName
    };
    cb(time);
  };

  invokeCb();
  setInterval(invokeCb, difSS * 1000);
};

exports.generateTimeEvents = generateTimeEvents;

var createTrack = function createTrack(isoTimeStart) {
  var k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  var secStart = iso2sec(isoTimeStart);
  return function (isoTime) {
    var sec = iso2sec(isoTime);
    var delta = Math.floor(k * (sec - secStart) / 60);
    return delta;
  };
};

exports.createTrack = createTrack;
var SchdStatus = {
  before: 'before',
  now: 'now',
  after: 'after',
  archived: 'archived',
  unknown: null
};

var createScheduleEvent = function createScheduleEvent(isoStart, durationMM) {
  var secArchive = iso2sec(globalSettings.conferenceFinish);
  var secStart = iso2sec(isoStart);
  var secEnd = secStart + durationMM * 60;
  return function (isoTime) {
    var sec = iso2sec(isoTime);
    var status = SchdStatus.unknown;
    var delta = sec - secStart;

    if (sec < secStart) {
      status = SchdStatus.before;
      delta = secStart - sec;
    }

    if (sec > secEnd) {
      status = SchdStatus.after;
      delta = sec - secEnd;
    }

    if (sec > secArchive) {
      status = SchdStatus.archived;
      delta = sec - secArchive;
    }

    if (sec >= secStart && sec <= secEnd) {
      status = SchdStatus.now;
    }

    return {
      status: status,
      deltaMM: Math.floor(delta / 60)
    };
  };
};

exports.createScheduleEvent = createScheduleEvent;

var lockCurrentTime = function lockCurrentTime(time) {
  lockedCurrentTime = time;
  console.warn("tmp.lockCurrentTime('".concat(lockedCurrentTime, "')"));
};

exports.lockCurrentTime = lockCurrentTime;

var getCurrentLocalISO = function getCurrentLocalISO() {
  if (lockedCurrentTime) {
    return _luxon.DateTime.fromISO(lockedCurrentTime).toISO();
  }

  return _luxon.DateTime.local().toISO();
};

exports.getCurrentLocalISO = getCurrentLocalISO;
var tmp = {
  getCurrentTime: getCurrentTime,
  setCurrentUTCTimeAndZone: setCurrentUTCTimeAndZone,
  convertEventTimeToISO: convertEventTimeToISO,
  lockCurrentTime: lockCurrentTime,
  getCurrentLocalISO: getCurrentLocalISO,
  lock1: function lock1() {
    return lockCurrentTime('2020-06-18T17:30:00.000+02:00');
  },
  lock2: function lock2() {
    return lockCurrentTime('2020-06-19T17:30:00.000+02:00');
  },
  lock3: function lock3() {
    return lockCurrentTime('2020-06-20T17:30:00.000+02:00');
  }
};
window.tmp = tmp;